@@ -145,7 +145,9 @@ mod test_custom_specs {
         case("custom/facet_grouped_bar_with_error_bars", 0.001, true),
         case("custom/facet_grouped_bar_with_error_bars_with_sort", 0.001, true),
         case("custom/binned_ordinal", 0.001, true),
-        case("custom/timeOffset_stocks", 0.001, true)
+        case("custom/timeOffset_stocks", 0.001, true),
+        case("custom/quakes_initial_selection", 0.001, true),
+        case("custom/aggregate_with_threshold", 0.001, true)
     )]
     fn test_image_comparison(spec_name: &str, tolerance: f64, extract_inline_values: bool) {
         println!("spec_name: {spec_name}");
